#!/bin/bash

source clone_sources_args.sh
source ../bash_utils/helpers.sh

# Arguments
IFS_BUNDLE_REPO=
IFS_BUNDLE_BRANCH=
GIT_BRANCH=
IFS_BUNDLE_ENV=
MN5_SOURCE_PATH=
FORCE=false


# 0. Check args:
parse_args "$@" 
check_required_args 
print_options

# 1. Cloning ifs-bundle to aux:
info "Cloning ifs bundle..."
git clone $IFS_BUNDLE_REPO $GIT_BRANCH aux_dir &> /dev/null
success "DONE"

REPO_HASH=$(git -C aux_dir rev-parse --short HEAD)
REPO_BRANCH=$(git -C aux_dir rev-parse --abbrev-ref HEAD)
REPO_BRANCH="${REPO_BRANCH//\//.}"
REPO_ID="ifs-bundle-${REPO_BRANCH}-${REPO_HASH}"

# 2. Check if this branch is already there:
[ -d $REPO_ID ] && fatal "IFS-BUNDLE VERSION $REPO_ID ALREADY INSTALLED!"

info "Using $REPO_ID as version"
mv aux_dir $REPO_ID


# 3. Apply ifs-bundle env (if required)
[ -z $IFS_BUNDLE_ENV ] || source $IFS_BUNDLE_ENV 

# 4. Build the bundle
info "Building ifs bundle..."
cd $REPO_ID
./ifs-bundle create -j 0 --shallow &> /dev/null
success "DONE"

# 5. Echo the lines to send to mn5
info "Sending data to $MN5_SOURCE_PATH ..."
[ -z $MN5_SOURCE_PATH ] && MN5_SOURCE_PATH=$DEF_MN5_DIR
MN5_SOURCE_PATH=$MN5_SOURCE_PATH/$REPO_ID
rsync -avP . $MN5_SOURCE_PATH &> /dev/null
success "DONE"